@@ -10,7 +10,7 @@ SPVM::Net::SSLeay::SSL_CTX - SSL_CTX data structure in OpenSSL
 
 =head1 Description
 
-Net::SSLeay::SSL_CTX class in L<SPVM> represents L<SSL_CTX|https://docs.openssl.org/master/man3/SSL_CTX_new/> data structure in OpenSSL.
+Net::SSLeay::SSL_CTX class in L<SPVM> represents C<SSL_CTX> data structure in OpenSSL.
 
 =head1 Usage
 
@@ -24,7 +24,7 @@ Net::SSLeay::SSL_CTX class in L<SPVM> represents L<SSL_CTX|https://docs.openssl.
 
 C<static method new : L<Net::SSLeay::SSL_CTX|SPVM::Net::SSLeay::SSL_CTX> ($method : L<Net::SSLeay::SSL_METHOD|SPVM::Net::SSLeay::SSL_METHOD>);>
 
-Calls native L<SSL_CTX_new|https://docs.openssl.org/master/man3/SSL_CTX_new/> function given the pointer value of $method, creates a new L<Net::SSLeay::SSL_CTX|SPVM::Net::SSLeay::SSL_CTX> object, sets the pointer value of the new object to the return value of the native function, and returns the new object.
+Calls native L<SSL_CTX_new|https://docs.openssl.org/master/man3/SSL_CTX_new> function given the pointer value of $method, creates a new L<Net::SSLeay::SSL_CTX|SPVM::Net::SSLeay::SSL_CTX> object, sets the pointer value of the new object to the return value of the native function, and returns the new object.
 
 C<SSL_MODE_AUTO_RETRY> mode is enabled.
 
@@ -38,25 +38,25 @@ If SSL_CTX_new failed, an exception is thrown with C<eval_error_id> set to the b
 
 C<method get_mode : long ();>
 
-Calls native L<SSL_CTX_get_mode|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_mode> function given the pointer value of the instance, and returns its return value.
+Calls native L<SSL_CTX_get_mode|https://docs.openssl.org/master/man3/SSL_CTX_get_mode> function given the pointer value of the instance, and returns its return value.
 
 =head2 set_mode
 
 C<method set_mode : long ($mode : long);>
 
-Calls native L<SSL_CTX_set_mode|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_mode> function given the pointer value of the instance, $mode, and returns its return value.
+Calls native L<SSL_CTX_set_mode|https://docs.openssl.org/master/man3/SSL_CTX_set_mode> function given the pointer value of the instance, $mode, and returns its return value.
 
 =head2 get0_param
 
 C<method get0_param : L<Net::SSLeay::X509_VERIFY_PARAM|SPVM::Net::SSLeay::X509_VERIFY_PARAM> ();>
 
-Calls native L<SSL_CTX_get0_param|https://docs.openssl.org/master/man3/SSL_CTX_get0_param/> function, creates a L<Net::SSLeay::X509_VERIFY_PARAM|SPVM::Net::SSLeay::X509_VERIFY_PARAM> object, sets the pointer value of the new object to the return value of the native function, and returns the new object.
+Calls native L<SSL_CTX_get0_param|https://docs.openssl.org/master/man3/SSL_CTX_get0_param> function, creates a L<Net::SSLeay::X509_VERIFY_PARAM|SPVM::Net::SSLeay::X509_VERIFY_PARAM> object, sets the pointer value of the new object to the return value of the native function, and returns the new object.
 
 =head2 load_verify_locations
 
 C<method load_verify_locations : int ($CAfile : string, $CApath : string);>
 
-Calls native L<SSL_CTX_load_verify_locations|https://docs.openssl.org/master/man3/SSL_CTX_load_verify_locations/> function given the pointer value of the instance, $CAfile, $CApath, and returns its return value.
+Calls native L<SSL_CTX_load_verify_locations|https://docs.openssl.org/master/man3/SSL_CTX_load_verify_locations> function given the pointer value of the instance, $CAfile, $CApath, and returns its return value.
 
 Exceptions:
 
@@ -66,7 +66,7 @@ If SSL_CTX_load_verify_locations failed, an exception is thrown with C<eval_erro
 
 C<method set_default_verify_paths : int ();>
 
-Calls native L<set_default_verify_paths|https://docs.openssl.org/master/man3/SSL_CTX_load_verify_locations/> function, and returns its return value.
+Calls native L<SSL_CTX_set_default_verify_paths|https://docs.openssl.org/master/man3/SSL_CTX_set_default_verify_paths> function, and returns its return value.
 
 Exceptions:
 
@@ -84,7 +84,7 @@ L<https://stackoverflow.com/questions/9507184/can-openssl-on-windows-use-the-sys
 
 C<method use_certificate_file : int ($file : string, $type : int = -1);>
 
-Calls native L<use_certificate_file|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate/> function given the pointer value of the instance, $file, $type, and returns its return value.
+Calls native L<SSL_CTX_use_certificate_file|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate_file> function given the pointer value of the instance, $file, $type, and returns its return value.
 
 If $type is a negative integer, $type is set to C<SSL_FILETYPE_PEM>.
 
@@ -98,7 +98,7 @@ If SSL_CTX_use_certificate_file failed, an exception is thrown with C<eval_error
 
 C<method use_certificate_chain_file : int ($file : string);>
 
-Calls native L<use_certificate_chain_file|https://docs.openssl.org/1.1.1/man3/SSL_CTX_use_certificate/> function given the pointer value of the instance, $file, and returns its return value.
+Calls native L<SSL_CTX_use_certificate_chain_file|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate_chain_file> function given the pointer value of the instance, $file, and returns its return value.
  
 Exceptions:
 
@@ -108,7 +108,7 @@ If SSL_CTX_use_certificate_chain_file failed, an exception is thrown with C<eval
 
 C<method use_PrivateKey_file : int ($file : string, $type : int = -1);>
 
-Calls native L<use_PrivateKey_file|https://docs.openssl.org/3.1/man3/SSL_CTX_use_certificate> function given the pointer value of the instance, $file, $type, and returns its return value.
+Calls native L<SSL_CTX_use_PrivateKey_file|https://docs.openssl.org/master/man3/SSL_CTX_use_PrivateKey_file> function given the pointer value of the instance, $file, $type, and returns its return value.
 
 If $type is a negative integer, $type is set to C<SSL_FILETYPE_PEM>.
 
@@ -122,13 +122,13 @@ If SSL_CTX_use_PrivateKey_file failed, an exception is thrown with C<eval_error_
 
 C<method use_PrivateKey : int ($pkey : L<Net::SSLeay::EVP_PKEY|SPVM::Net::SSLeay::EVP_PKEY>);>
 
-Calls native L<SSL_CTX_use_PrivateKey|https://docs.openssl.org/master/man3/SSL_CTX_use_certificate> function given the pointer value of the instance, $pkey, pushes $pkey to the end of L</"pkeys_list"> field, and returns the return value of the native function.
+Calls native L<SSL_CTX_use_PrivateKey|https://docs.openssl.org/master/man3/SSL_CTX_use_PrivateKey> function given the pointer value of the instance, $pkey, pushes $pkey to the end of L</"pkeys_list"> field, and returns the return value of the native function.
 
 =head2 set_cipher_list
 
 C<method set_cipher_list : int ($str : string);>
 
-Calls native L<set_cipher_list|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list/> function given the pointer value of the instance, $str, and returns its return value.
+Calls native L<SSL_CTX_set_cipher_list|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list> function given the pointer value of the instance, $str, and returns its return value.
 
 Exceptions:
 
@@ -140,7 +140,7 @@ If SSL_CTX_set_cipher_list failed, an exception is thrown with C<eval_error_id>
 
 C<method set_ciphersuites : int ($str : string);>
 
-Calls native L<set_ciphersuites|https://docs.openssl.org/master/man3/SSL_CTX_set_cipher_list/> function given the pointer value of the instance, $str, and returns its return value.
+Calls native L<SSL_CTX_set_ciphersuites|https://docs.openssl.org/master/man3/SSL_CTX_set_ciphersuites> function given the pointer value of the instance, $str, and returns its return value.
 
 Exceptions:
 
@@ -152,31 +152,31 @@ If SSL_CTX_set_ciphersuites failed, an exception is thrown with C<eval_error_id>
 
 C<method get_cert_store : L<Net::SSLeay::X509_STORE|SPVM::Net::SSLeay::X509_STORE> ();>
 
-Calls native L<SSL_CTX_set_cert_store|https://docs.openssl.org/master/man3/SSL_CTX_set_cert_store/> function, creates a new L<Net::SSLeay::X509_STORE|SPVM::Net::SSLeay::X509_STORE>, sets the pointer value of the new object to the return value of the native function, and returns the new object.
+Calls native L<SSL_CTX_set_cert_store|https://docs.openssl.org/master/man3/SSL_CTX_set_cert_store> function, creates a new L<Net::SSLeay::X509_STORE|SPVM::Net::SSLeay::X509_STORE>, sets the pointer value of the new object to the return value of the native function, and returns the new object.
 
 =head2 set_options
 
 C<method set_options : long ($options : long);>
 
-Calls native L<set_options|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_options> function given the pointer value of the instance, $options, and returns its return value.
+Calls native L<SSL_CTX_set_options|https://docs.openssl.org/master/man3/SSL_CTX_set_options> function given the pointer value of the instance, $options, and returns its return value.
 
 =head2 get_options
 
 C<method get_options : long ();>
 
-Calls native L<SSL_CTX_get_options|https://docs.openssl.org/3.1/man3/SSL_CTX_set_options/> function, and returns its return value.
+Calls native L<SSL_CTX_get_options|https://docs.openssl.org/master/man3/SSL_CTX_get_options> function, and returns its return value.
 
 =head2 clear_options
 
 C<method clear_options : long ($options : long);>
 
-Calls native L<SSL_CTX_clear_options|https://docs.openssl.org/3.1/man3/SSL_CTX_set_options/> function given the pointer value of the instance, $options, and returns its return value.
+Calls native L<SSL_CTX_clear_options|https://docs.openssl.org/master/man3/SSL_CTX_clear_options> function given the pointer value of the instance, $options, and returns its return value.
 
 =head2 set_alpn_protos
 
 C<method set_alpn_protos : int ($protos : string, $protos_len : int = -1);>
 
-Calls native L<SSL_CTX_set_alpn_protos|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_alpn_select_cb> function given the protocals $ptotos and the length $protos_len, and returns its return value.
+Calls native L<SSL_CTX_set_alpn_protos|https://docs.openssl.org/master/man3/SSL_CTX_set_alpn_protos> function given the protocals $ptotos and the length $protos_len, and returns its return value.
 
 If $protos_len is less than 0, it is set to the length of $protos.
 
@@ -196,7 +196,7 @@ Calls L<Net::SSLeay::Util#convert_to_wire_format|SPVM::Net::SSLeay::Util/"conver
 
 C<method set1_groups_list : int ($list : string);>
 
-Calls native L<SSL_CTX_set1_groups_list|https://docs.openssl.org/3.1/man3/SSL_CTX_set1_curves> function given the group list $list, and returns its return value.
+Calls native L<SSL_CTX_set1_groups_list|https://docs.openssl.org/master/man3/SSL_CTX_set1_groups_list> function given the group list $list, and returns its return value.
 
 Exceptions:
 
@@ -208,7 +208,7 @@ If set1_groups_list failed, an exception is thrown with C<eval_error_id> set to
 
 C<method set_post_handshake_auth : void ($val : int);>
 
-Calls native L<SSL_CTX_set_post_handshake_auth|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_verify> function given the pointer value of the instance, $val.
+Calls native L<SSL_CTX_set_post_handshake_auth|https://docs.openssl.org/master/man3/SSL_CTX_set_post_handshake_auth> function given the pointer value of the instance, $val.
 
 =head2 set_min_proto_version
 
@@ -224,7 +224,7 @@ If SSL_CTX_set_min_proto_version failed, an exception is thrown with C<eval_erro
 
 C<method set_client_CA_list : void ($list : L<X509_NAME|SPVM::X509_NAME>[]);>
 
-Calls native L<SSL_CTX_set_client_CA_list|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_client_CA_list> function given the pointer value of the instance, $list.
+Calls native L<SSL_CTX_set_client_CA_list|https://docs.openssl.org/master/man3/SSL_CTX_set_client_CA_list> function given the pointer value of the instance, $list.
 
 Exceptions:
 
@@ -234,7 +234,7 @@ The list $list must be defined. Otherwise an exception is thrown.
 
 C<method add_client_CA : int ($cacert : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
 
-Calls native L<SSL_CTX_add_client_CA|https://docs.openssl.org/master/man3/SSL_CTX_set0_CA_list> function given the pointer value of the instance, $cacert, and returns its return value.
+Calls native L<SSL_CTX_add_client_CA|https://docs.openssl.org/master/man3/SSL_CTX_add_client_CA> function given the pointer value of the instance, $cacert, and returns its return value.
 
 Exceptions:
 
@@ -246,7 +246,7 @@ If add_client_CA failed, an exception is thrown with C<eval_error_id> set to the
 
 C<method add_extra_chain_cert : long ($x509 : L<Net::SSLeay::X509|SPVM::Net::SSLeay::X509>);>
 
-Calls native L<SSL_CTX_add_extra_chain_cert|https://docs.openssl.org/1.1.1/man3/SSL_CTX_add_extra_chain_cert/> function given the pointer value of the instance, $x509, sets the C<no_free> flag of $x509 is set to 1, and returns its return value.
+Calls native L<SSL_CTX_add_extra_chain_cert|https://docs.openssl.org/master/man3/SSL_CTX_add_extra_chain_cert> function given the pointer value of the instance, $x509, sets the C<no_free> flag of $x509 is set to 1, and returns its return value.
 
 Exceptions:
 
@@ -258,41 +258,41 @@ If SSL_CTX_add_extra_chain_cert failed, an exception is thrown with C<eval_error
 
 C<method set_verify : void ($mode : int, $verify_callback : L<Net::SSLeay::Callback::Verify|SPVM::Net::SSLeay::Callback::Verify> = undef);>
 
-Calls native L<SSL_CTX_set_verify|https://docs.openssl.org/master/man3/SSL_CTX_set_verify/> function given the pointer value of the instance, $mode, $verify_callback.
+Calls native L<SSL_CTX_set_verify|https://docs.openssl.org/master/man3/SSL_CTX_set_verify> function given the pointer value of the instance, $mode, $verify_callback.
 
 =head2 set_alpn_select_cb
 
 C<method set_alpn_select_cb : void ($cb : Net::SSLeay::Callback::AlpnSelect);>
 
-Calls native L<SSL_CTX_set_alpn_select_cb|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_alpn_select_cb> function given $cb, NULL.
+Calls native L<SSL_CTX_set_alpn_select_cb|https://docs.openssl.org/master/man3/SSL_CTX_set_alpn_select_cb> function given $cb, NULL.
 
 =head2 set_alpn_select_cb_with_protocols
 
 C<method set_alpn_select_cb_with_protocols : void ($protocols : string[]);>
 
-Calls native L<SSL_CTX_set_alpn_select_cb|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_alpn_select_cb> function defined to select $protocols.
+Calls native L<SSL_CTX_set_alpn_select_cb|https://docs.openssl.org/master/man3/SSL_CTX_set_alpn_select_cb> function defined to select $protocols.
 
 =head2 set_default_passwd_cb
 
 C<method set_default_passwd_cb : void ($cb : L<Net::SSLeay::Callback::PemPassword|SPVM::Net::SSLeay::Callback::PemPassword>);>
 
-Calls native L<SSL_CTX_set_default_passwd_cb|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_default_passwd_cb> function given $cb, NULL, and returns its return value.
+Calls native L<SSL_CTX_set_default_passwd_cb|https://docs.openssl.org/master/man3/SSL_CTX_set_default_passwd_cb> function given $cb, NULL, and returns its return value.
 
-$arg is expected to be passed to native L<SSL_CTX_set_default_passwd_cb_userdata|https://docs.openssl.org/1.0.2/man3/SSL_CTX_set_default_passwd_cb> function.
+$arg is expected to be passed to native L<SSL_CTX_set_default_passwd_cb_userdata|https://docs.openssl.org/master/man3/SSL_CTX_set_default_passwd_cb_userdata> function.
 
 =head2 set_tlsext_servername_callback
 
 C<method set_tlsext_servername_callback : long ($cb : L<Net::SSLeay::Callback::TlsextServername|SPVM::Net::SSLeay::Callback::TlsextServername>);>
 
-Calls native L<SSL_CTX_set_tlsext_servername_callback|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_tlsext_servername_callback> function given $cb, NULL, and returns its return value.
+Calls native L<SSL_CTX_set_tlsext_servername_callback|https://docs.openssl.org/master/man3/SSL_CTX_set_tlsext_servername_callback> function given $cb, NULL, and returns its return value.
 
-$arg is expected to be passed to native L<SSL_CTX_set_tlsext_servername_arg|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_tlsext_servername_callback> function.
+$arg is expected to be passed to native L<SSL_CTX_set_tlsext_servername_arg|https://docs.openssl.org/master/man3/SSL_CTX_set_tlsext_servername_arg> function.
 
 =head2 DESTROY
 
 C<method DESTROY : void ();>
 
-Calls native L<SSL_CTX_free|https://docs.openssl.org/3.1/man3/SSL_CTX_free/> function given the pointer value of the instance if C<no_free> flag of the instance is not a true value.
+Calls native L<SSL_CTX_free|https://docs.openssl.org/master/man3/SSL_CTX_free> function given the pointer value of the instance unless C<no_free> flag of the instance is a true value.
 
 =head1 See Also
 
